package de.fitko.fitconnect.api.services.auth;

import de.fitko.fitconnect.api.domain.auth.OAuthToken;
import de.fitko.fitconnect.api.domain.model.submission.SubmissionRequest;
import de.fitko.fitconnect.api.exceptions.internal.AuthenticationException;

/**
 * A Service that provides an interface to authenticate against the Fit-Connect API in order
 * to send a {@link SubmissionRequest}.
 *
 * @see <a href="https://docs.fitko.de/fit-connect/docs/getting-started/authentication">Fit-Connect documentation on authentication</a>
 *
 */
public interface OAuthService {

    /**
     * Authenticates the sender against the FIT-Co API and retrieves an authentication token
     *
     * @param clientId     - a unique identifier within the FIT-Co platform environment
     * @param clientSecret - a secret that is only known by the application and the OAuth server
     * @param scope        - OAuth scope(s) that determine if a submission is accepted by the client
     * @return {@link OAuthToken} that holds the access-token
     * @throws {@link AuthenticationException} if an error occurred
     */
    OAuthToken authenticate(String clientId, String clientSecret, String... scope) throws AuthenticationException;
}
